@@ -70,7 +70,7 @@ do_links (GtkWidget *do_widget)
       gtk_widget_show (label);
     }
 
-  if (!GTK_WIDGET_VISIBLE (window))
+  if (!gtk_widget_get_visible (window))
     {
       gtk_widget_show (window);
     }
