@@ -17,13 +17,16 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
+#include "config.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
 #include <string.h>
+
+#undef GDK_DISABLE_DEPRECATED
+
 #include <gtk/gtk.h>
-#include <gdk-pixbuf/gdk-pixbuf-loader.h>
+#include <gdk-pixbuf/gdk-pixbuf.h>
 
 #include "test-inline-pixbufs.h"
 
@@ -322,6 +325,7 @@ expose_func (GtkWidget *drawing_area, GdkEventExpose *event, gpointer data)
 
 	if (gdk_pixbuf_get_has_alpha (pixbuf)) {
 		GdkPixbuf *dest;
+                cairo_t *cr;
 	  
 		gdk_window_set_back_pixmap (drawing_area->window, NULL, FALSE);
 	  
@@ -335,11 +339,13 @@ expose_func (GtkWidget *drawing_area, GdkEventExpose *event, gpointer data)
 					    GDK_INTERP_BILINEAR, 255,
 					    event->area.x, event->area.y, 16, 0xaaaaaa, 0x555555);
 		
-		gdk_draw_pixbuf (drawing_area->window, drawing_area->style->fg_gc[GTK_STATE_NORMAL], dest,
-				 0, 0, event->area.x, event->area.y,
-				 event->area.width, event->area.height,
-				 GDK_RGB_DITHER_NORMAL, event->area.x, event->area.y);
-		
+                cr = gdk_cairo_create (drawing_area->window);
+
+                gdk_cairo_set_source_pixbuf (cr, dest, 0, 0);
+                gdk_cairo_rectangle (cr, &event->area);
+                cairo_fill (cr);
+
+                cairo_destroy (cr);
 		g_object_unref (dest);
 	} else {
 		gdk_draw_rgb_image (drawing_area->window,
@@ -358,11 +364,11 @@ expose_func (GtkWidget *drawing_area, GdkEventExpose *event, gpointer data)
 static void
 config_func (GtkWidget *drawing_area, GdkEventConfigure *event, gpointer data)
 {
+#if 0
 	GdkPixbuf *pixbuf;
     
 	pixbuf = (GdkPixbuf *)g_object_get_data (G_OBJECT (drawing_area), "pixbuf");
 
-#if 0
 	if (((event->width) != gdk_pixbuf_get_width (pixbuf)) ||
 	    ((event->height) != gdk_pixbuf_get_height (pixbuf)))
 		gdk_pixbuf_scale (pixbuf, event->width, event->height);
@@ -383,7 +389,7 @@ new_testrgb_window (GdkPixbuf *pixbuf, gchar *title)
 	w = gdk_pixbuf_get_width (pixbuf);
 	h = gdk_pixbuf_get_height (pixbuf);
 
-	window = gtk_widget_new (gtk_window_get_type (),
+	window = g_object_new (gtk_window_get_type (),
 				 "GtkObject::user_data", NULL,
 				 "GtkWindow::type", GTK_WINDOW_TOPLEVEL,
 				 "GtkWindow::title", title ? title : "testrgb",
@@ -504,7 +510,7 @@ progressive_updated_callback (GdkPixbufLoader* loader, guint x, guint y, guint w
 
 static int readlen = 4096;
 
-extern void pixbuf_init ();
+extern void pixbuf_init (void);
 
 void size_func (GdkPixbufLoader *loader, gint width, gint height, gpointer data)
 {
@@ -525,7 +531,7 @@ main (int argc, char **argv)
 
 	gtk_init (&argc, &argv);
 
-	/*	gdk_rgb_set_verbose (TRUE); */
+	/*	gdk_rgb_set_verbose (TRUE);*/
 
 	gtk_widget_set_default_colormap (gdk_rgb_get_colormap ());
 
@@ -628,7 +634,7 @@ main (int argc, char **argv)
 
 			status.readlen = readlen;
 
-                        status.timeout = g_timeout_add (100, update_timeout, &status);
+                        status.timeout = gdk_threads_add_timeout (100, update_timeout, &status);
                 }
 #endif
 	}
